function plot_electric_field (k, Nlines, nfig)

%
%  Example problem for electric field lines
%
%  Ex = E0*sign(x)*cos(k*y)*exp(-k*abs(x))
%  Ey = E0*sin(k*y)*exp(-k*abs(x))
%
%  Test cases 
%            plot_electric_field(0.25, 20, 1)
%            plot_electric_field(0.25, 40, 3)   


%k = 0.25;
E0 = 1;

xmin = -2.*(1./k);
xmax = +2.*(1./k);
dx   = (xmax-xmin)./Nlines;
ymin = -pi.*(1./k)-0.0051;
ymax = +pi.*(1./k)+0.0051;
dy   = (ymax-ymin)./Nlines;

[x,y] = meshgrid(xmin:dx:xmax, ymin:dy:ymax);

%[x,y]= meshgrid(xmin:dx:xmax,-2.501*pi:5.002*pi/50:2.501*pi)

Ex = E0.*sign(x).*cos(k.*y).*exp(-k.*abs(x));
Ey = E0.*sin(k.*y).*exp(-k.*abs(x));

figure(nfig)
quiver(x,y,Ex,Ey) 
axis image 

hold on



yy = -1*pi-0.2:(2*pi+0.2)/40:1*pi+0.2;
%yy = -1*pi-0.001:2*pi/30:1*pi+0.001;
n=length(yy);

for m=1:n
xp=0.01;
yp=yy(m);

fieldlines(x,y,Ex,Ey,xp,yp)
fieldlines(x,y,Ex,Ey,-xp,yp)

end

set(gca,'Fontsize',14,'Fontweight','bold')
xlabel('x','Fontsize',12,'FontWeight','bold')
ylabel('y','Fontsize',12,'FontWeight','bold')
title(['k = ',num2str(k,3),' m^{-1}, E_0 = ',num2str(E0),' V/m'],'Fontsize',12,'FontWeight','bold')
hold off



nfig = nfig +1;
figure(nfig)
hold off

for m=1:n
xp=0.01;
yp=yy(m);
fieldlines(x,y,Ex,Ey,xp,yp)
hold on
fieldlines(x,y,Ex,Ey,-xp,yp)
end

axis equal
axis([xmin xmax ymin ymax])
set(gca,'Fontsize',14,'Fontweight','bold')
xlabel('x','Fontsize',12,'FontWeight','bold')
ylabel('y','Fontsize',12,'FontWeight','bold')
title(['k = ',num2str(k,3),' m^{-1}, E_0 = ',num2str(E0),' V/m'],'Fontsize',12,'FontWeight','bold')

hold off




