function plot_electric_field_1

%
%  Example problem for electric field lines
%                    ^
%                    |
%  +lambda o         |         o -lambda
%      (-xo,yo)      |      (xo,yo)
%  --------------------------------------->
%                    |
%                    |
%                    |


x0 = 1;
y0 = 1;


xmin1 = -2*x0;
xmax1 =  0;
xmin2 =  0;
xmax2 = +2*x0;
dx1   = (xmax1-xmin1)./85;
dx2   = (xmax2-xmin2)./85;
ymin = -1*y0;
ymax = +3*y0;
dy   = (ymax-ymin)./85;
r0=0.05;

[x1,y1] = meshgrid(xmin1:dx1:xmax1, ymin:dy:ymax);
[x2,y2] = meshgrid(xmin2:dx2:xmax2, ymin:dy:ymax);

E0 = 1;

rplus1  = ((x1+x0).^2+(y1-y0).^2);
rminus1 = ((x1-x0).^2+(y1-y0).^2);

Ex1 = E0.*(x1+x0)./rplus1 - E0.*(x1-x0)./rminus1;
Ey1 = E0.*(y1-y0)./rplus1 - E0.*(y1-y0)./rminus1;


rplus2 = ((x2+x0).^2+(y2-y0).^2);
rminus2 = ((x2-x0).^2+(y2-y0).^2);

Ex2 = E0.*(x2+x0)./rplus2 - E0.*(x2-x0)./rminus2;
Ey2 = E0.*(y2-y0)./rplus2 - E0.*(y2-y0)./rminus2;


figure(1)
quiver(x1,y1,Ex1,Ey1) 
axis image 
hold on
quiver(x2,y2,Ex2,Ey2)

phi=0.:2*pi/40:2*pi;
xx1 = -x0 + r0.*cos(phi);
yy1 = +y0 + r0.*sin(phi);
xx2 = +x0 + r0.*cos(phi);
yy2 = +y0 + r0.*sin(phi);
n=length(phi);

for m=1:n
xp1=xx1(m);
yp1=yy1(m);
xp2=xx2(m);
yp2=yy2(m);

fieldlines(x1,y1,Ex1,Ey1,xp1,yp1)
fieldlines(x2,y2,Ex2,Ey2,xp2,yp2)

end

xlabel('x','Fontsize',12,'FontWeight','bold')
ylabel('y','Fontsize',12,'FontWeight','bold')
title(['\lambda /2\pi\epsilon = ',num2str(E0,3),' Volt'],'Fontsize',12,'FontWeight','bold')


Ex2=-Ex2;
Ey2=-Ey2;
quiver(x2,y2,Ex2,Ey2)

figure(2)

for m=1:n
xp1=xx1(m);
yp1=yy1(m);
xp2=xx2(m);
yp2=yy2(m);

fieldlines(x1,y1,Ex1,Ey1,xp1,yp1)
hold on
fieldlines(x2,y2,Ex2,Ey2,xp2,yp2)
end

axis equal
axis([xmin1 xmax2 ymin/2 ymax/2+1])
xlabel('x','Fontsize',12,'FontWeight','bold')
ylabel('y','Fontsize',12,'FontWeight','bold')
title(['\lambda /2\pi\epsilon = ',num2str(E0,3),' Volt'],'Fontsize',12,'FontWeight','bold')

