function plot_electric_field_2(a,b,Nterms,Nlines)

%
%  Example problem for electric field lines
%                    ^ y
%                  b |--------------|
%                  0 |              |
%                    |              |
%  ---------------------------------|------>
%                    |       V0    a      x
%                    |
%                    |

V0=1;
Npoints =120;

xmin = 0;
xmax = a;
dx   = (xmax-xmin)/Npoints;

ymin = 0;
ymax = b;
dy   = (ymax-ymin)/Npoints;

[x,y] = meshgrid(xmin:dx:xmax, ymin:dy:ymax);

mm =  0:1:Nterms;
km = (2*mm+1)*(pi/(2*a));
Cm = (4*V0/pi)*(1./(2.*mm+1)).*(1./cosh(km.*b));

nx = length(x);
ny = length(y);

for ix = 1:nx
  for iy = 1:ny

    Ex(ix,iy) = -sum(  Cm.*km.*cos(km.*x(ix,iy)).*cosh(km.*(y(ix,iy)-b)) );  
    Ey(ix,iy) = -sum(  Cm.*km.*sin(km.*x(ix,iy)).*sinh(km.*(y(ix,iy)-b)) );

  end
end


for ix = 1:nx
  for iy = 1:ny
    
    F(ix,iy) = sum(  Cm.*sin(km.*x(ix,iy)).*cosh(km.*(y(ix,iy)-b)) );

  end
end


xx1 =  xmin:dx:xmax;
yy1 =  ymin:dy:ymax;





figure(1)
quiver(x,y,Ex,Ey) 
axis image 
hold on


ii = 1:1:(Nlines-1);
xx = ii*(a/Nlines);
yy = ones(length(ii))*0.01;


for m=1:Nlines-1
xp=xx(m);
yp=yy(m);

fieldlines(x,y,Ex,Ey,xp,yp)

end

axis('equal')
set(gca,'Fontsize',14,'Fontweight','bold')
xlabel('x','Fontsize',12,'FontWeight','bold')
ylabel('y','Fontsize',12,'FontWeight','bold')
title(['a = ',num2str(a),',  b = ',num2str(b)],'Fontsize',12,'FontWeight','bold')




figure(2)

for m=1:Nlines-1
xp=xx(m);
yp=yy(m);

fieldlines(x,y,Ex,Ey,xp,yp)

hold on

end

cont = [0.05 0.1 0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.85 0.875 0.9 0.95];
contour(x,y,F,cont,'Linewidth',1,'Color','b')
axis equal
%axis image 
%axis xy

set(gca,'Fontsize',14,'Fontweight','bold')
xlabel('x','Fontsize',12,'FontWeight','bold')
ylabel('y','Fontsize',12,'FontWeight','bold')
axis([xmin xmax ymin ymax])
title(['Red=Field Lines, Blue=Equal Potential  -- a = ',num2str(a), ...
       ',  b = ',num2str(b)],'Fontsize',11,'FontWeight','bold')

figure(3)
imagesc(xx1,yy1,F)
axis image 
axis xy
axis('equal')
set(gca,'Fontsize',14,'Fontweight','bold')
xlabel('x','Fontsize',12,'FontWeight','bold')
ylabel('y','Fontsize',12,'FontWeight','bold')
title(['Potential \Phi (x,y)'])
hold on

figure(4)

[CS,H] = contour(xx1,yy1,F,cont,'Linewidth',1.5,'Color','b');
clabel(CS,H,cont);
axis image 
axis xy
axis('equal')
set(gca,'Fontsize',14,'Fontweight','bold')
xlabel('x','Fontsize',12,'FontWeight','bold')
ylabel('y','Fontsize',12,'FontWeight','bold')
title(['Equipotential Lines'])